/******************************************************************************
 *            echecs_var.c                                                    *
 *                                                                            *
 *  Copyright  2006  gerald.dumas                                             *
 *  linechec@laposte.net                                                      *
 ******************************************************************************
 *                                                                            *
 *  This program is free software; you can redistribute it and/or modify      *
 *  it under the terms of the GNU General Public License as published by      *
 *  the Free Software Foundation; either version 2 of the License, or         *
 *  any later version.                                                        *
 *                                                                            *
 *  This program is distributed in the hope that it will be useful,           *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
 *  GNU General Public License for more details.                              *
 *                                                                            *
 *  You should have received a copy of the GNU General Public License         *
 *  along with this program; if not, write to the Free Software               *
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*
 ******************************************************************************/
 
/* déclarations liminaires des différentes variables globales */
#include "echecs_var.h"

/* Déclaration d'un tableau contenant toutes les rosaces de
    déplacement des différentes pièces                          */
gint8 rosace[7][9]={{-11,-13,-12,-24,0,0,0,0},			// pion blanc
									{11,13,12,24,0,0,0,0},					// pions noirs
									{-10,-14,-23,-25,10,14,23,25,0},// cavalier
									{-1,-11,-12,-13,1,11,12,13,0},	// roi
									{-1,-12,1,12,0,0,0,0},					// tour
									{-11,-13,11,13,0,0,0,0},				// fou
									{-1,-11,-12,-13,1,11,12,13,0}};	// dame

// tableau de correspondance entre les pièces et leur rosace.
gint8 corres_piece[7] = {pion,pion,cavalier,roi,tour,fou,dame};
/*--------------------------------------------------------------*/

GList *liste_coups_jouables;	// Pointeur sur la liste des coups jouables principale utilisé
															// pour la jouabilité.

//typedef struct struct_piece type_piece;		// Définition générale d'une pièce.

struct struct_echiquier echiquier[144];

type_piece table_piece [33];	/* Tableau comportant toutes les pièces en jeu
                                        avec tous leurs coups jouables et différentes
                                        variables d'état.*/

gboolean partie_en_cours;			// Indique si une partie est en cours de jeu.
gboolean partie_enregistree;	// Si une partie est en cours, indique si elle est sauvée
															// à la position actuelle.

struct struct_position_echiquier tab_sauve_partie [200];	// tableau de sauvegarde de la partie en cours
gint num_coup_joue;						// n° du coup joué ( les n° impairs sont les coups blancs )
gint humain_joue;							// bascule pour la couleur jouable sur l'échiquier
gint couleur_humain;					// Couleur joué par l'humain.
gboolean gnuchess;						// Indique si c'est Gnuchess qui joue contre l'humain
gchar prise_en_passant;				// Vrai si une prise en passant est possible.

GKeyFile *key_file_config;		// Structure contenant toutes les variables de configuration

// Variables initialisées avec les options de commande.
gchar *connex="";					// IP du serveur FICS
gchar *filename="";				// Nom du fichier à charger au démarrage
gchar *username="";				// Nom de l'utilisateur
gboolean debug=FALSE;			// Affiche des indications sur les cases pointées

GOptionEntry entries[] = 
{
	{ "filename", 'f', 0, G_OPTION_ARG_STRING, &filename, "Chargement d'une partie (le fichier ne\n\t\t\t\t\tdoit contenir qu'une seule partie)\n", "nom d'un fichier" },
	{	"user", 'u', 0, G_OPTION_ARG_STRING, &username, "Nom de l'utilisateur (futur)\n", "nom" },
	{	"connex", 'c', 0, G_OPTION_ARG_STRING, &connex, "Connexion réseau à un serveur de jeu de\n\t\t\t\t\ttype FICS (utilisez conjointement\n\t\t\t\t\tl'option -u, le serveur FICS a besoin\n\t\t\t\t\td'un nom) (futur)\n", "adresse" },
	{	"debug", 'd', 0, G_OPTION_ARG_NONE, &debug, "Affiche des indications sur les cases\n\t\t\t\t\tpointées par la souris.\n", NULL },
	{ NULL }
};
